==> react-bootstrap-0.2.0.tgz: package/es/components/Popup/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';

import './index.css';

var Popup = function Popup(_ref) {
  var closeButtonTitle = _ref.closeButtonTitle,
      className = _ref.className,
      onClose = _ref.onClose,
      children = _ref.children,
      props = _objectWithoutProperties(_ref, ['closeButtonTitle', 'className', 'onClose', 'children']);

  return React.createElement(
    'div',
    { className: 'popup' },
    React.createElement('button', { className: 'popup-close-bg', onClick: onClose, title: closeButtonTitle }),
    React.createElement(
      'div',
      { className: 'popup-content' },
      React.createElement(
        'div',
        _extends({ className: 'popup-body ' + className }, props),
        children
      )
    )
  );
};

Popup.propTypes = process.env.NODE_ENV !== "production" ? {
  closeButtonTitle: PropTypes.string,
  className: PropTypes.string,
  onClose: PropTypes.func,
  children: PropTypes.node
} : {};

Popup.defaultProps = {
  closeButtonTitle: 'Close',
  className: '',
  onClose: function onClose() {},
  children: null
};

export default Popup;

==> react-bootstrap-0.2.2.tgz: package/es/components/Popup/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';

import './index.css';

var Popup = function Popup(_ref) {
  var closeButtonTitle = _ref.closeButtonTitle,
      className = _ref.className,
      onClose = _ref.onClose,
      children = _ref.children,
      props = _objectWithoutProperties(_ref, ['closeButtonTitle', 'className', 'onClose', 'children']);

  return React.createElement(
    'div',
    { className: 'popup text-body' },
    React.createElement('button', { title: closeButtonTitle, type: 'button', className: 'popup-close-bg', onClick: onClose }),
    React.createElement(
      'div',
      { className: 'popup-content' },
      React.createElement(
        'div',
        _extends({ className: 'popup-body ' + className }, props),
        children
      )
    )
  );
};

Popup.propTypes = process.env.NODE_ENV !== "production" ? {
  closeButtonTitle: PropTypes.string,
  className: PropTypes.string,
  onClose: PropTypes.func,
  children: PropTypes.node
} : {};

Popup.defaultProps = {
  closeButtonTitle: 'Close',
  className: '',
  onClose: function onClose() {},
  children: null
};

export default Popup;
